import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../LexModelsV2Client";
import { DeleteBotAliasRequest, DeleteBotAliasResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteBotAliasCommand}.
 */
export interface DeleteBotAliasCommandInput extends DeleteBotAliasRequest {
}
/**
 * @public
 *
 * The output of {@link DeleteBotAliasCommand}.
 */
export interface DeleteBotAliasCommandOutput extends DeleteBotAliasResponse, __MetadataBearer {
}
declare const DeleteBotAliasCommand_base: {
    new (input: DeleteBotAliasCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteBotAliasCommandInput, DeleteBotAliasCommandOutput, LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DeleteBotAliasCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteBotAliasCommandInput, DeleteBotAliasCommandOutput, LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Deletes the specified bot alias.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { LexModelsV2Client, DeleteBotAliasCommand } from "@aws-sdk/client-lex-models-v2"; // ES Modules import
 * // const { LexModelsV2Client, DeleteBotAliasCommand } = require("@aws-sdk/client-lex-models-v2"); // CommonJS import
 * const client = new LexModelsV2Client(config);
 * const input = { // DeleteBotAliasRequest
 *   botAliasId: "STRING_VALUE", // required
 *   botId: "STRING_VALUE", // required
 *   skipResourceInUseCheck: true || false,
 * };
 * const command = new DeleteBotAliasCommand(input);
 * const response = await client.send(command);
 * // { // DeleteBotAliasResponse
 * //   botAliasId: "STRING_VALUE",
 * //   botId: "STRING_VALUE",
 * //   botAliasStatus: "Creating" || "Available" || "Deleting" || "Failed",
 * // };
 *
 * ```
 *
 * @param DeleteBotAliasCommandInput - {@link DeleteBotAliasCommandInput}
 * @returns {@link DeleteBotAliasCommandOutput}
 * @see {@link DeleteBotAliasCommandInput} for command's `input` shape.
 * @see {@link DeleteBotAliasCommandOutput} for command's `response` shape.
 * @see {@link LexModelsV2ClientResolvedConfig | config} for LexModelsV2Client's `config` shape.
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>The action that you tried to perform couldn't be completed because
 *          the resource is in a conflicting state. For example, deleting a bot
 *          that is in the CREATING state. Try your request again. </p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The service encountered an unexpected condition. Try your request
 *          again.</p>
 *
 * @throws {@link PreconditionFailedException} (client fault)
 *  <p>Your request couldn't be completed because one or more request
 *          fields aren't valid. Check the fields in your request and try
 *          again.</p>
 *
 * @throws {@link ServiceQuotaExceededException} (client fault)
 *  <p>You have reached a quota for your bot. </p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Your request rate is too high. Reduce the frequency of
 *          requests.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>One of the input parameters in your request isn't valid. Check the
 *          parameters and try your request again.</p>
 *
 * @throws {@link LexModelsV2ServiceException}
 * <p>Base exception class for all service exceptions from LexModelsV2 service.</p>
 *
 *
 * @public
 */
export declare class DeleteBotAliasCommand extends DeleteBotAliasCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteBotAliasRequest;
            output: DeleteBotAliasResponse;
        };
        sdk: {
            input: DeleteBotAliasCommandInput;
            output: DeleteBotAliasCommandOutput;
        };
    };
}
